/*
 * Copyright (C) 2008 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package tests.sql;

import dalvik.annotation.TestLevel;
import dalvik.annotation.TestTargetClass;
import dalvik.annotation.TestTargetNew;

import junit.framework.TestCase;

import java.sql.SQLInput;

@TestTargetClass(SQLInput.class)
public class SQLInputTest extends TestCase {

    /**
     * Test method for {@link java.sql.SQLInput#readString()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readString",
          args = {}
    )
    public void testReadString() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readBoolean()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readBoolean",
          args = {}
        )
    public void testReadBoolean() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readByte()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readByte",
          args = {}
        )public void testReadByte() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readShort()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readShort",
          args = {}
        )
    public void testReadShort() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readInt()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readInt",
          args = {}
        )
    public void testReadInt() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readLong()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readLong",
          args = {}
        )
    public void testReadLong() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readFloat()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readFloat",
          args = {}
        )
    public void testReadFloat() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readDouble()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readDouble",
          args = {}
        )
    public void testReadDouble() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readBigDecimal()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readBigDecimal",
          args = {}
        )
    public void testReadBigDecimal() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readBytes()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readBytes",
          args = {}
        )
    public void testReadBytes() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readDate()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readDate",
          args = {}
        )
    public void testReadDate() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readTime()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readTime",
          args = {}
        )
    public void testReadTime() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readTimestamp()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readTimestamp",
          args = {}
        )
    public void testReadTimestamp() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readCharacterStream()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readCharacterStream",
          args = {}
        )
    public void testReadCharacterStream() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readAsciiStream()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readAsciiStream",
          args = {}
        )
    public void testReadAsciiStream() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readBinaryStream()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readBinaryStream",
          args = {}
        )
    public void testReadBinaryStream() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readObject()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readObject",
          args = {}
        )
    public void testReadObject() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readRef()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readRef",
          args = {}
        )
    public void testReadRef() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readBlob()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readBlob",
          args = {}
    )
    public void testReadBlob() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readClob()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readClob",
          args = {}
        )
    public void testReadClob() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readArray()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readArray",
          args = {}
        )
    public void testReadArray() {
        fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#wasNull()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "wasNull",
          args = {}
        )
    public void testWasNull() {
    fail("Not yet implemented");
    }

    /**
     * Test method for {@link java.sql.SQLInput#readURL()}.
     */
    @TestTargetNew(
      level = TestLevel.NOT_FEASIBLE,
      notes = "",
          method = "readURL",
          args = {}
    )
    public void testReadURL() {
        fail("Not yet implemented");
    }

}
